"use strict";

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

window.InceptioCallback = {};
window.InceptioCallback.registFunction = function (functionId, callback) {
	window.InceptioCallback[functionId] = function (res) {
		if (isJsonString(res)) {
			res = JSON.parse(res);
		}
		callback(res);
	};
	return "window.InceptioCallback." + functionId;
};

function isJsonString(str) {
	try {
		if (_typeof(JSON.parse(str)) == "object") {
			return true;
		}
	} catch (e) {}
	return false;
}
//支持promise
var inceptio = {};

/**
 *支持网关验证和安全通道的网络请求接口(Promise)
 *
 * @param {Object} params
 * @returns 返回Promise对象
 */
inceptio.securityRequest = function (params) {
	return new Promise(function (resolve, reject) {
		var promiseParams = Object.assign(params, {
			success: function success(res) {
				resolve(res);
			},
			fail: function fail(err) {
				reject(err);
			}
		});
        let success = window.InceptioCallback.registFunction("securityRequest_success", promiseParams.success);
	    var fail = window.InceptioCallback.registFunction("securityRequest_fail", promiseParams.fail);
        var newParams = Object.assign(promiseParams, {
            success: success,
            fail: fail
        });
	    window.android.securityRequest(JSON.stringify(newParams));
	});
};
/**
 *是否开启安全通道(Promise)
 *
 * @param {function} ChannelCallback
 * @returns 返回Promise对象
 */
inceptio.securityChannelEnable = function () {
	return new Promise(function (resolve, reject) {
	    var callback = window.InceptioCallback.registFunction("securityChannelEnable_callback", function(res){
            resolve(res)
        });
    	var params = {
    		callback: callback
    	};
    	window.android.securityChannelEnable(JSON.stringify(params));
	});
};
/**
 *获取网关验证需要的请求头(Promise)
 *
 * @returns 返回Promise对象
 */
inceptio.getGatewayHeaders = function (url,content) {
	return new Promise(function (resolve, reject) {
	    let callback = window.InceptioCallback.registFunction("getGatewayHeaders_callback", function(res){
	        resolve(res)
	    });
        var params = {
            url:url,
            content:content,
            callback: callback
        };
        window.android.getGatewayHeaders(JSON.stringify(params));
	});
};
/**
 *获取客户端配置文件(Promise)
 *
 * @returns 返回Promise对象
 */
inceptio.getClientConfig = function () {
	return new Promise(function (resolve, reject) {
		 let callback = window.InceptioCallback.registFunction("getClientConfig_callback", function(res){
            resolve(res)
        });
        var params = {
            callback: callback
        };
        window.android.getClientConfig(JSON.stringify(params));
	});
};

/**
 *关闭当前浏览器
 *
 */
inceptio.closeWindow = function (content) {
	return window.android.closeWindow();
};

/**
 *安全通道开启时解密方法(Promise)
 *
 * @param {String} content
 * @returns
 */
inceptio.securityRequestDecrypt = function (content) {
	return new Promise(function (resolve, reject) {
		var params = {
			content: content,
			success: function success(res) {
				resolve(res);
			},
			fail: function fail(err) {
				reject(err);
			}
		};
		var success = window.InceptioCallback.registFunction("securityRequestDecrypt_success", params.success);
        var fail = window.InceptioCallback.registFunction("securityRequestDecrypt_fail", params.fail);
        var newParams = Object.assign(params, {
            success: success,
            fail: fail
        });
        window.android.securityRequestDecrypt(JSON.stringify(newParams));
	});
};
/**
 *安全通道开启时加密方法(Promise)
 *
 * @param {String} content
 * @returns
 */
inceptio.securityRequestEncrypt = function (content) {
	return new Promise(function (resolve, reject) {
		var params = {
			content: content,
			success: function success(res) {
				resolve(res);
			},
			fail: function fail(err) {
				reject(err);
			}
		};
		var success = window.InceptioCallback.registFunction("securityRequestEncrypt_success", params.success);
        var fail = window.InceptioCallback.registFunction("securityRequestEncrypt_fail", params.fail);
        var newParams = Object.assign(params, {
            success: success,
            fail: fail
        });
        window.android.securityRequestEncrypt(JSON.stringify(newParams));
	});
};

window.inceptio = inceptio;

inceptio.__inited__ = true;